part of 'menu_cubit.dart';

abstract class MenuState {}

class MenuInitial extends MenuState {}

class MenuLoading extends MenuState {}

class MenuLoaded extends MenuState {
  final String userAgreementHtml;
  MenuLoaded(this.userAgreementHtml);
}


class MenuItemsLoaded extends MenuState {
final List<Map<String, Object>> menuSections;
  MenuItemsLoaded(this.menuSections);
}
class MenuError extends MenuState {
  final String message;

  MenuError(this.message);
}

class MenuNameUpdated extends MenuState {
  final String name;

  MenuNameUpdated(this.name);
}
